@@ -3,7 +3,7 @@ use warnings;
 
 package Test::Mocha;
 # ABSTRACT: Test Spy/Stub Framework
-$Test::Mocha::VERSION = '0.60';
+$Test::Mocha::VERSION = '0.61';
 
 use Carp qw( croak );
 use Exporter qw( import );
@@ -14,11 +14,13 @@ use Test::Mocha::CalledOk::AtMost;
 use Test::Mocha::CalledOk::Between;
 use Test::Mocha::Mock;
 use Test::Mocha::Types 'NumRange', Mock => { -as => 'MockType' };
-use Test::Mocha::Util qw( getattr get_method_call is_called );
+use Test::Mocha::Util
+  qw( getattr get_method_call is_called extract_method_name );
 use Types::Standard qw( ArrayRef HashRef Num slurpy );
 
 our @EXPORT = qw(
   mock
+  class_mock
   stub
   returns
   throws
@@ -290,7 +292,7 @@ sub clear (@) {
     my @mocks = @_;
 
     ## no critic (ProhibitBooleanGrep)
-    croak 'clear() must be given one or more mock objects'
+    croak 'clear() must be given mock objects only'
       if !@mocks || grep { !MockType->check($_) } @mocks;
     ## use critic
 
@@ -311,6 +313,30 @@ sub SlurpyHash () {
 }
 ## use critic
 
+sub class_mock {
+    my ($mocked_class) = @_;
+
+    my $module_file = join( q{/}, split q{::}, $mocked_class ) . '.pm';
+    my $caller_pkg = caller;
+    no strict 'refs';  ## no critic (TestingAndDebugging::ProhibitNoStrict)
+
+    # make sure the real module is not already loaded
+    croak "Package '$mocked_class' is already loaded so it cannot be mocked"
+      if defined ${ $caller_pkg . '::INC' }{$module_file};
+
+    # check if package has already been mocked
+    croak "Package '$mocked_class' is already mocked"
+      if defined *{ $mocked_class . '::AUTOLOAD' }{CODE};
+
+    my $mock = mock($mocked_class);
+
+    *{ $mocked_class . '::AUTOLOAD' } = sub {
+        my ($method) = extract_method_name( our $AUTOLOAD );
+        $mock->$method(@_);
+    };
+    return $mock;
+}
+
 1;
 
 __END__
@@ -321,9 +347,13 @@ __END__
 
 Test::Mocha - Test Spy/Stub Framework
 
+=for html
+<a href="https://travis-ci.org/stevenl/Test-Mocha"><img src="https://travis-ci.org/stevenl/Test-Mocha.svg?branch=master" alt="Build Status"></a>
+<a href='https://coveralls.io/r/stevenl/Test-Mocha?branch=master'><img src='https://coveralls.io/repos/stevenl/Test-Mocha/badge.png?branch=master' alt='Coverage Status' /></a>
+
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -492,18 +522,22 @@ tests and you must count calls to C<called_ok()> in your test plans.
     called_ok { $warehouse->remove($item, 50) };
     # prints: ok 1 - remove("book", 50) was called 1 time(s)
 
-An option may be specified to constrain the test.
+The following functions are available to verify the number of calls:
 
 =over 4
 
 =item C<times>
 
 Specifies the number of times the given method is expected to be called.
-The default is 1 if no other option is specified.
+C<times(1)> is the default if no option is specified.
 
     called_ok { $mock->method(@args) } times(3);
     # prints: ok 1 - method(@args) was called 3 time(s)
 
+Note: C<times()> may clash with the built-in function with the same name.
+You may explicitly specify which one you want by qualifying it as
+C<&times(3)> or C<CORE::times>.
+
 =item C<atleast>
 
 Specifies the minimum number of times the given method is expected to be
@@ -548,11 +582,12 @@ default.
     is $method_call->name,            'remove_inventory';
     is_deeply [$method_call->args],   ['book', 50];
     is_deeply [$method_call->caller], ['test.pl', 5];
-    is "$method_call", 'remove_inventory("book", 50) called at test.pl line 5';
+    is $method_call->stringify,       'remove_inventory("book", 50)';
+    is $method_call->stringify_long,  'remove_inventory("book", 50) called at test.pl line 5';
 
 C<inspect()> returns a list of method calls matching the given method call
 specification. It can be useful for debugging failed C<called_ok()> calls.
-Or use it in place of a complex C<called_ok()> call to break it down into
+Or use it in place of a complex call to C<called_ok()> to break it down into
 smaller tests.
 
 The method call objects have the following accessor methods:
@@ -571,9 +606,17 @@ C<args> - The list of arguments passed to the method call.
 
 C<caller> - The file and line number from which the method was called.
 
+=item *
+
+C<stringify> - The name and arguments as a string.
+
+=item *
+
+C<stringify_long> - The name, arguments, file and line number as a string.`
+
 =back
 
-They are also C<string> overloaded.
+They are also string overloaded with the value from C<stringify>.
 
 =head2 inspect_all
 
@@ -656,15 +699,33 @@ they will match empty argument lists.
 
 =for Pod::Coverage SlurpyArray SlurpyHash
 
-=head1 TO DO
+=head1 MOCKING CLASS METHODS (experimental)
 
-=over 4
+=head2 class_mock
 
-=item *
+C<class_mock()> creates a mock for stubbing class methods and module functions.
 
-Module functions and class methods
+    class_mock 'Some::Class';
 
-=back
+To stub a class method or module function:
+
+    stub { Some::Class->some_class_method() } returns 'something';
+    is( Some::Class->some_class_method(), 'something' );
+
+    stub { Some::Class::some_module_function() } returns 'something';
+    is( Some::Class::some_module_function(), "something" );
+
+Validation is handled similarly.
+
+    called_ok { Some::Class->some_class_method() } "some_class_method called";
+    called_ok { Some::Class::some_module_function() } "some_module_function called";
+
+Note: The original class that you mock must not be imported before you have
+finished stubbing the class. This means that if your module under test C<use>s
+it, then you must C<use_ok> or C<require> the test module after stubbing the
+mock class.
+
+Also note: Currently you cannot stub new().
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -673,7 +734,7 @@ Module functions and class methods
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-test-mocha at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Mocha>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Test-Mocha>. You will be automatically notified of any
 progress on the request by the system.
 
 =head1 AUTHOR
@@ -688,13 +749,15 @@ Charles (CYCLES).
 It is inspired by the popular L<Mockito|http://code.google.com/p/mockito/>
 for Java and Python by Szczepan Faber.
 
+The class_mock method was contributed by Scott Davis.
+
 =head1 SEE ALSO
 
 L<Test::MockObject>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Lee.
+This software is copyright (c) 2015 by Steven Lee.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
