@@ -1,6 +1,6 @@
 package Test::Mocha::Mock;
 # ABSTRACT: Mock objects
-$Test::Mocha::Mock::VERSION = '0.60';
+$Test::Mocha::Mock::VERSION = '0.61';
 use strict;
 use warnings;
 
@@ -35,7 +35,7 @@ my $CAN = Test::Mocha::MethodStub->new(
                 $AUTOLOAD = $method_name;
                 goto &AUTOLOAD;
             };
-          }
+        }
     ],
 );
 
@@ -62,18 +62,20 @@ my $ISA = Test::Mocha::MethodStub->new(
 
 sub new {
     # uncoverable pod
-    my ( $class, %args ) = @_;
+    my ( $class, $mocked_class ) = @_;
 
-    # ArrayRef[ MethodCall ]
-    $args{calls} = [];
-
-    # $method_name => ArrayRef[ MethodStub ]
-    $args{stubs} = {
-        can  => [$CAN],
-        DOES => [$DOES_UC],
-        does => [$DOES_LC],
-        isa  => [$ISA],
-    };
+    my %args = (
+        # ArrayRef[ MethodCall ]
+        calls => [],
+        # $method_name => ArrayRef[ MethodStub ]
+        mocked_class => $mocked_class,
+        stubs        => {
+            can  => [$CAN],
+            DOES => [$DOES_UC],
+            does => [$DOES_LC],
+            isa  => [$ISA],
+        },
+    );
     return bless \%args, $class;
 }
 
@@ -81,6 +83,18 @@ sub AUTOLOAD {
     my ( $self, @args ) = @_;
     my $method_name = extract_method_name($AUTOLOAD);
 
+    # If a class method or module function, then transform method name
+    my $mocked_class = getattr( $self, 'mocked_class' );
+    if ($mocked_class) {
+        if ( $args[0] eq $mocked_class ) {
+            shift @args;
+            $method_name = "${mocked_class}->${method_name}";
+        }
+        else {
+            $method_name = "${mocked_class}::${method_name}";
+        }
+    }
+
     undef $last_method_call;
     undef $last_execution;
 
@@ -143,8 +157,8 @@ sub isa {
     return 1 if $class eq __PACKAGE__;
 
     # In order to allow mock methods to be called with other mocks as
-    # arguments, mocks cannot isa() type constraints, which are not allowed
-    # as arguments.
+    # arguments, mocks cannot have isa() called with type constraints,
+    # which are not allowed as arguments.
     return if exists $Isnota{$class};
 
     $AUTOLOAD = 'isa';
@@ -182,7 +196,7 @@ sub ref {  ## no critic (ProhibitBuiltinHomonyms)
     goto &AUTOLOAD;
 }
 
-# Don't let AUTOLOAD() handle DESTROY()
+# Don't let AUTOLOAD() handle DESTROY() so that object can be destroyed
 sub DESTROY { }
 
 1;
